==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Hatch</name>
    <message>
        <location filename="../Hatch.js" line="+56"/>
        <source>No boundary selected.</source>
        <translation>未选中边界.</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Loop not closed at point %1/%2.</source>
        <translation>环在点 %1/%2 未闭合.</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation>每个边界实体必须是直线，弧，圆，椭圆弧，椭圆，折线或曲线. 发现：</translation>
    </message>
    <message>
        <location filename="../HatchInit.js" line="+2"/>
        <source>&amp;Hatch</source>
        <translation>图案填充(&amp;H)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw hatch or solid fill</source>
        <translation>图案或实心填充</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>图案填充</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>实心填充</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>图案</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>模式</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>角度：</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>缩放：</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Hatch</name>
    <message>
        <source>No boundary selected.</source>
        <translation type="vanished">未选中边界.</translation>
    </message>
    <message>
        <source>Loop not closed at point %1/%2.</source>
        <translation type="vanished">环在点 %1/%2 未闭合.</translation>
    </message>
    <message>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation type="vanished">每个边界实体必须是直线，弧，圆，椭圆弧，椭圆，折线或曲线. 发现：</translation>
    </message>
    <message>
        <location filename="../Hatch.js" line="+72"/>
        <source>Hatch Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show hatch tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Hatch</source>
        <translation>图案填充(&amp;H)</translation>
    </message>
    <message>
        <source>Draw hatch or solid fill</source>
        <translation type="vanished">图案或实心填充</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>图案填充</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>实心填充</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>图案</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>模式</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>角度：</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>缩放：</translation>
    </message>
</context>
</TS>
